(window.webpackJsonp=window.webpackJsonp||[]).push([[0],{Yv6K:function(c,e,r){"use strict";r.d(e,"a",(function(){return b}));var s=r("ofXK"),t=r("8MG2"),n=r("3Pt+"),i=r("tyNb"),o=r("fXoL");let b=(()=>{class c{}return c.\u0275mod=o.Jb({type:c}),c.\u0275inj=o.Ib({factory:function(e){return new(e||c)},imports:[[s.c,n.g,i.g,t.a]]}),c})()},pgGW:function(c,e,r){"use strict";r.d(e,"a",(function(){return d}));var s=r("fXoL"),t=r("aLtf"),n=r("8MG2"),i=r("ofXK"),o=r("tyNb");const b=function(c){return["/","e",c]};function l(c,e){if(1&c&&(s.Rb(0,"clr-dg-row"),s.Rb(1,"clr-dg-cell"),s.Dc(2),s.Qb(),s.Rb(3,"clr-dg-cell"),s.Dc(4),s.Qb(),s.Rb(5,"clr-dg-cell"),s.Mb(6,"clr-icon"),s.Qb(),s.Rb(7,"clr-dg-cell"),s.Mb(8,"clr-icon"),s.Qb(),s.Rb(9,"clr-dg-cell"),s.Rb(10,"button",1),s.Dc(11),s.Qb(),s.Qb(),s.Qb()),2&c){const c=e.$implicit,r=s.bc();s.zb(2),s.Ec(c.order),s.zb(2),s.Ec(c.id),s.zb(2),s.Ab("shape",c.mandatory?"check":"times"),s.zb(2),s.Ab("shape",r.exerciseProgress[c.id]?"check":"times"),s.zb(2),s.hc("routerLink",s.lc(6,b,c.id)),s.zb(1),s.Fc(" ",r.exerciseProgress[c.id]?"Restart":"Start"," ")}}let d=(()=>{class c{constructor(c){this.progress=c,this.exercises=[],this.exerciseProgress={}}ngOnInit(){this.exercises=this.exercises.sort((c,e)=>c.order-e.order),this.exercises.forEach(c=>{const e=this.progress.solveStatus(c.id);e&&(this.exerciseProgress[c.id]=e)})}}return c.\u0275fac=function(e){return new(e||c)(s.Lb(t.a))},c.\u0275cmp=s.Fb({type:c,selectors:[["app-exercise-list"]],inputs:{exercises:"exercises"},decls:11,vars:1,consts:[[4,"ngFor","ngForOf"],[1,"btn","btn-link",3,"routerLink"]],template:function(c,e){1&c&&(s.Rb(0,"clr-datagrid"),s.Rb(1,"clr-dg-column"),s.Dc(2,"#"),s.Qb(),s.Rb(3,"clr-dg-column"),s.Dc(4,"ID"),s.Qb(),s.Rb(5,"clr-dg-column"),s.Dc(6,"Mandatory"),s.Qb(),s.Rb(7,"clr-dg-column"),s.Dc(8,"Done"),s.Qb(),s.Mb(9,"clr-dg-column"),s.Bc(10,l,12,8,"clr-dg-row",0),s.Qb()),2&c&&(s.zb(10),s.hc("ngForOf",e.exercises))},directives:[n.h,n.eb,n.gb,n.ab,n.hb,n.j,n.db,i.o,n.r,n.fb,n.i,n.cb,n.x,o.d],styles:[""]}),c})()}}]);